abjadbooktools.OutputFormat
===========================

.. abjad-lineage:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat

.. autoclass:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.code_block_closing
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.code_block_opening
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.code_indent
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.image_block
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.image_format
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__call__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__eq__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__ge__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__gt__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__le__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__lt__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__ne__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__repr__
   :noindex:
